# Powerset

Powerset is a set of 3 functions made in Python to work with lists as powerlists founded in mathematical powersets.

Powerset is a module to work with lists and create powersets of the lists, if you want your list to be passed as a set make sure you dont have duplicates making list(set(originalList)) to your originalList.

We have 3 methods:

  powerset(list) will return the powerset of the list.
  
  length(list) will return the cardinality (number of members) of any subset on the powerset of your list.
  
  powernums(list) will return the number of subset for any given cardinality of the subsets in the powerset of your list.
  


